Instructions:
1. You are given a sentence. Your task is to break the sentence down into a ist of atomic facts.
2. An atomic fact is a sentence containing a singular piece of information.
3. Each atomic fact in the outputted list should check a different piece of information.
4. Use the previous examples to learn how to do this.
5. You should only output the atomic facts as a list, with each item starting with "- ". Do not include other formatting.
6. Your task is to do this for the last sentence that is given.